@@ -26,6 +26,11 @@ from .common.logger import log
 from .common.exceptions import CrawlerError
 
 
+OPERATING_SYSTEM = sys.platform
+FIREFOX_OPTIONS = webdriver.firefox.options.Options()
+if OPERATING_SYSTEM == 'win32':
+    FIREFOX_OPTIONS = webdriver.FirefoxOptions()
+
 # typing
 WebElement = webdriver.remote.webelement.WebElement
 WebElements = list[WebElement]
@@ -69,7 +74,7 @@ ATTR_SELECTOR = {
 webdrivers = {
     "firefox": {
         "webdriver": webdriver.Firefox,
-        "options": webdriver.firefox.options.Options(),
+        "options": FIREFOX_OPTIONS,
         # "profile": firefox_profile,
         "url": "https://github.com/mozilla/geckodriver/releases"
     },
@@ -145,6 +150,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
             self.logger.error(str(err))
             self.logger.error(message)
             sys.exit(1)
+        self.wait = WebDriverWait(self.driver, self.timeout)
 
     def quitdriver(method: Callable) -> Callable:  # pylint: disable=E0213
         """ "safe quit webdriver to avoid memory leakages"""
@@ -203,6 +209,17 @@ class Crawler:  # pylint: disable=too-many-public-methods
         """
         self.driver.set_window_rect(x=0, y=0, width=960, height=960)
 
+    @quitdriver
+    def half_right_window(
+        self,
+    ):
+        """
+        half_right_window
+
+        Resize and shifts window to the right.
+        """
+        self.driver.set_window_rect(x=960, y=0, width=960, height=960)
+
     @quitdriver
     def element(self,
                 value: str,
@@ -616,8 +633,8 @@ class Crawler:  # pylint: disable=too-many-public-methods
         """
         wait = WebDriverWait(self.driver, self.timeout)
 
-        def run():
-            return self.driver.execute_script(script)
+        def run(driver=self.driver):
+            return driver.execute_script(script)
 
         result = wait.until(run)
         return result
@@ -682,7 +699,7 @@ class Crawler:  # pylint: disable=too-many-public-methods
             Whatever JavaScript returns.
         """
         script = document_query_selector(selector)
-        script += f'.{attribute}="{value}";'
+        script += f'{attribute}="{value}";'
         return self.run_script(script)
 
     @quitdriver
